@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY   = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION     = '1.007_001';
+	$Type::Tiny::VERSION     = '1.007_002';
 	$Type::Tiny::XS_VERSION  = '0.011';
 }
 
@@ -460,6 +460,8 @@ sub _build_compiled_check
 {
 	my $self = shift;
 	
+	local our $AvoidCallbacks = 0;
+	
 	if ($self->_is_null_constraint and $self->has_parent)
 	{
 		return $self->parent->compiled_check;
@@ -760,6 +762,7 @@ sub _perlcode
 {
 	my $self = shift;
 	
+	local our $AvoidCallbacks = 1;
 	return $self->inline_check('$_')
 		if $self->can_be_inlined;
 	
@@ -1000,6 +1003,8 @@ sub _build_complementary_type
 	$opts{display_name} =~ s/^\~{2}//;
 	$opts{inlined} = sub { shift; "not(".$self->inline_check(@_).")" }
 		if $self->can_be_inlined;
+	$opts{display_name} = $opts{name} = $self->{complement_name}
+		if $self->{complement_name};
 	return "Type::Tiny"->new(%opts);
 }
 
@@ -1346,6 +1351,74 @@ Type::Tiny - tiny, yet Moo(se)-compatible type constraint
 
 =head1 SYNOPSIS
 
+ use v5.12;
+ use strict;
+ use warnings;
+ 
+ package Horse {
+   use Moo;
+   use Types::Standard qw( Str Int Enum ArrayRef Object );
+   use Type::Params qw( compile );
+   use namespace::autoclean;
+   
+   has name => (
+     is       => 'ro',
+     isa      => Str,
+     required => 1,
+   );
+   has gender => (
+     is       => 'ro',
+     isa      => Enum[qw( f m )],
+   );
+   has age => (
+     is       => 'rw',
+     isa      => Int->where( '$_ >= 0' ),
+   );
+   has children => (
+     is       => 'ro',
+     isa      => ArrayRef[Object],
+     default  => sub { return [] },
+   );
+   
+   sub add_child {
+     state $check = compile( Object, Object );  # method signature
+     
+     my ($self, $child) = $check->(@_);         # unpack @_
+     push @{ $self->children }, $child;
+     
+     return $self;
+   }
+ }
+ 
+ package main;
+ 
+ my $boldruler = Horse->new(
+   name    => "Bold Ruler",
+   gender  => 'm',
+   age     => 16,
+ );
+ 
+ my $secretariat = Horse->new(
+   name    => "Secretariat",
+   gender  => 'm',
+   age     => 0,
+ );
+ 
+ $boldruler->add_child( $secretariat );
+
+=head1 STATUS
+
+This module is covered by the
+L<Type-Tiny stability policy|Type::Tiny::Manual::Policies/"STABILITY">.
+
+=head1 DESCRIPTION
+
+This documents the internals of the L<Type::Tiny> class. L<Type::Tiny::Manual>
+is a better starting place if you're new.
+
+L<Type::Tiny> is a small class for creating Moose-like type constraint
+objects which are compatible with Moo, Moose and Mouse.
+
    use Scalar::Util qw(looks_like_number);
    use Type::Tiny;
    
@@ -1370,22 +1443,9 @@ Type::Tiny - tiny, yet Moo(se)-compatible type constraint
       has favourite_number => (is => "ro", isa => $NUM);
    }
 
-=head1 STATUS
-
-This module is covered by the
-L<Type-Tiny stability policy|Type::Tiny::Manual::Policies/"STABILITY">.
-
-=head1 DESCRIPTION
-
-L<Type::Tiny> is a tiny class for creating Moose-like type constraint
-objects which are compatible with Moo, Moose and Mouse.
-
 Maybe now we won't need to have separate MooseX, MouseX and MooX versions
 of everything? We can but hope...
 
-This documents the internals of L<Type::Tiny>. L<Type::Tiny::Manual> is
-a better starting place if you're new.
-
 =head2 Constructor
 
 =over
@@ -2046,6 +2106,28 @@ dumps. (Default limit is 72.)
 This is a package variable (rather than get/set class methods) to allow
 for easy localization.
 
+=item C<< $Type::Tiny::AvoidCallbacks >>
+
+If this variable is set to true (you should usually do it in a
+C<local> scope), it acts as a hint for type constraints, when
+generating inlined code, to avoid making any callbacks to
+variables and functions defined outside the inlined code itself.
+
+This should have the effect that C<< $type->inline_check('$foo') >>
+will return a string of code capable of checking the type on
+Perl installations that don't have Type::Tiny installed. This
+is intended to allow Type::Tiny to be used with things like
+L<Mite>.
+
+The variable works on the honour system. Types need to explicitly
+check it and decide to generate different code based on its
+truth value. The bundled types in L<Types::Standard>,
+L<Types::Common::Numeric>, and L<Types::Common::String> all do.
+(B<StrMatch> is sometimes unable to, and will issue a warning
+if it needs to rely on callbacks when asked not to.)
+
+Most normal users can ignore this.
+
 =back
 
 =head2 Environment
