@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Common::Numeric::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Common::Numeric::VERSION   = '1.007_001';
+	$Types::Common::Numeric::VERSION   = '1.007_002';
 }
 
 $Types::Common::Numeric::VERSION =~ tr/_//d;
@@ -61,7 +61,7 @@ $meta->add_type(
 	inlined    => sub {
 		if ($pos_int) {
 			my $xsub = Type::Tiny::XS::get_subname_for($_[0]->name);
-			return "$xsub($_[1])" if $xsub;
+			return "$xsub($_[1])" if $xsub && !$Type::Tiny::AvoidCallbacks;
 		}
 		undef, qq($_ > 0);
 	},
@@ -76,7 +76,7 @@ $meta->add_type(
 	inlined    => sub {
 		if ($posz_int) {
 			my $xsub = Type::Tiny::XS::get_subname_for($_[0]->name);
-			return "$xsub($_[1])" if $xsub;
+			return "$xsub($_[1])" if $xsub && !$Type::Tiny::AvoidCallbacks;
 		}
 		undef, qq($_ >= 0);
 	},
